from typing import Optional

from .base import RiotGamesApiBase
from .models.spectator import CurrentGameInfo


class SpectatorApiV4(RiotGamesApiBase):
    def get_current_game(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> CurrentGameInfo:
        data = self._request(f"/lol/spectator/v4/active-games/by-summoner/{summoner_id}", platform)

        return CurrentGameInfo.parse_obj(data)



from typing import Optional, List

from pydantic import parse_obj_as

from .models.league import LeagueEntryDto
from .base import RiotGamesApiBase


class LeagueExpApiV4(RiotGamesApiBase):
    def get_entries(
            self,
            queue: str,
            tier: str,
            division: str,
            platform: Optional[str] = None
    ) -> List[LeagueEntryDto]:
        data = self._request(f"/lol/league-exp/v4/entries/{queue}/{tier}/{division}", platform)

        return parse_obj_as(List[LeagueEntryDto], data)



from typing import Optional

from .models.summoner import SummonerDto
from .base import RiotGamesApiBase


class SummonerApiV4(RiotGamesApiBase):
    def get_summoner_by_account_id(
            self,
            account_id: str,
            platform: Optional[str] = None
    ) -> SummonerDto:
        data = self._request(f"/lol/summoner/v4/summoners/by-account/{account_id}", platform)

        return SummonerDto.parse_obj(data)

    def get_summoner_by_name(
            self,
            summoner_name: str,
            platform: Optional[str] = None
    ) -> SummonerDto:
        data = self._request(f"/lol/summoner/v4/summoners/by-name/{summoner_name}", platform)

        return SummonerDto.parse_obj(data)

    def get_summoner_by_puuid(
            self,
            puuid: str,
            platform: Optional[str] = None
    ) -> SummonerDto:
        data = self._request(f"/lol/summoner/v4/summoners/by-puuid/{puuid}", platform)

        return SummonerDto.parse_obj(data)

    def get_summoner_by_summoner_id(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> SummonerDto:
        data = self._request(f"/lol/summoner/v4/summoners/{summoner_id}", platform)

        return SummonerDto.parse_obj(data)



from typing import Optional, List

from .base import RiotGamesApiBase
from .models.match import MatchDto, MatchlistDto, MatchTimelineDto


class MatchApiV4(RiotGamesApiBase):
    def get_match(
            self,
            match_id: int,
            platform: Optional[str] = None
    ) -> MatchDto:
        data = self._request(f"/lol/match/v4/matches/{match_id}", platform)

        return MatchDto.parse_obj(data)

    def get_matchlists(
            self,
            account_id: str,
            platform: Optional[str] = None,
            *,
            champion: Optional[List[int]] = None,
            queue: Optional[List[int]] = None,
            season: Optional[List[int]] = None,
            end_time: Optional[int] = None,
            begin_time: Optional[int] = None,
            end_index: Optional[int] = None,
            begin_index: Optional[int] = None
    ) -> MatchlistDto:
        params = {
            "champion": champion,
            "queue": queue,
            "season": season,
            "endTime": end_time,
            "beginTime": begin_time,
            "endIndex": end_index,
            "beginIndex": begin_index
        }

        data = self._request(f"/lol/match/v4/matchlists/by-account/{account_id}", platform, params)

        return MatchlistDto.parse_obj(data)

    def get_match_timelines(
            self,
            match_id: int,
            platform: Optional[str] = None
    ) -> MatchTimelineDto:
        data = self._request(f"/lol/match/v4/timelines/by-match/{match_id}", platform)

        return MatchTimelineDto.parse_obj(data)

    def get_match_ids_by_tournament_code(
            self,
            tournament_code: str,
            platform: Optional[str] = None
    ) -> List[int]:
        return self._request(f"/lol/match/v4/matches/by-tournament-code/{tournament_code}/ids", platform)

    def get_match_by_tournament_code(
            self,
            match_id: int,
            tournament_code: str,
            platform: Optional[str] = None
    ) -> MatchDto:
        data = self._request(f"/lol/match/v4/matches/{match_id}/by-tournament-code/{tournament_code}", platform)

        return MatchDto.parse_obj(data)



from .base import BaseModel


class ChampionMasteryDto(BaseModel):
    champion_points_until_next_level: int
    chest_granted: bool
    champion_id: int
    last_play_time: int
    champion_level: int
    summoner_id: str
    champion_points: int
    champion_points_since_last_level: int
    tokens_earned: int



from typing import Optional

from .base import RiotGamesApiBase
from .models.lol_status import PlatformDataDto


class LolStatusApiV4(RiotGamesApiBase):
    def get_status(
            self,
            platform: Optional[str] = None
    ) -> PlatformDataDto:
        data = self._request(f"/lol/status/v4/platform-data", platform)

        return PlatformDataDto.parse_obj(data)



from requests import Session, RequestException
from typing import Optional, Any, Dict
from urllib.parse import urljoin

from .exceptions import RiotGamesApiException
from .context import RiotGamesApiContext


class RiotGamesApiBase:
    def __init__(
            self,
            ctx: RiotGamesApiContext,
            session: Optional[Session] = None
    ):
        self._ctx = ctx
        self._session = session or Session()
    
    def _request(
            self,
            path: str,
            platform: Optional[str] = None,
            params: Optional[Dict[str, Any]] = None
    ):
        try:
            headers = {
                "X-Riot-Token": self._ctx.token
            }
            base_url = self._ctx.get_base_url(platform)

            response = self._session.request(
                "GET",
                urljoin(base_url, path),
                headers=headers,
                params=params
            )
            response.raise_for_status()

            return response.json()
        except RequestException as e:
            raise RiotGamesApiException from e



from typing import Optional, Dict, List

from .base import BaseModel


class PlayerDto(BaseModel):
    platform_id: str
    account_id: str
    summoner_name: str
    summoner_id: str
    current_platform_id: str
    current_account_id: str
    match_history_uri: str
    profile_icon: int


class ParticipantIdentityDto(BaseModel):
    participant_id: int
    player: PlayerDto


class ParticipantTimelineDto(BaseModel):
    participant_id: int
    creeps_per_min_deltas: Dict[str, int]
    xp_per_min_deltas: Dict[str, int]
    gold_per_min_deltas: Dict[str, int]
    cs_diff_per_min_deltas: Optional[Dict[str, int]]
    xp_diff_per_min_deltas: Optional[Dict[str, int]]
    damage_taken_per_min_deltas: Dict[str, int]
    damage_taken_diff_per_min_deltas: Optional[Dict[str, int]]
    role: str
    lane: str


class ParticipantStatsDto(BaseModel):
    participant_id: int
    win: bool
    item0: int
    item1: int
    item2: int
    item3: int
    item4: int
    item5: int
    item6: int
    kills: int
    deaths: int
    assists: int
    largest_killing_spree: int
    largest_multi_kill: int
    killing_sprees: int
    longest_time_spent_living: int
    double_kills: int
    triple_kills: int
    quadra_kills: int
    penta_kills: int
    unreal_kills: int
    total_damage_dealt: int
    magic_damage_dealt: int
    physical_damage_dealt: int
    true_damage_dealt: int
    largest_critical_strike: int
    total_damage_dealt_to_champions: int
    magic_damage_dealt_to_champions: int
    physical_damage_dealt_to_champions: int
    true_damage_dealt_to_champions: int
    total_heal: int
    total_units_healed: int
    damage_self_mitigated: int
    damage_dealt_to_objectives: int
    damage_dealt_to_turrets: int
    vision_score: int
    time_c_cing_others: int
    total_damage_taken: int
    magical_damage_taken: int
    physical_damage_taken: int
    true_damage_taken: int
    gold_earned: int
    gold_spent: int
    turret_kills: int
    inhibitor_kills: int
    total_minions_killed: int
    neutral_minions_killed: int
    neutral_minions_killed_team_jungle: int
    neutral_minions_killed_enemy_jungle: int
    total_time_crowd_control_dealt: int
    champ_level: int
    vision_wards_bought_in_game: int
    sight_wards_bought_in_game: int
    wards_placed: int
    wards_killed: int
    first_blood_kill: bool
    first_blood_assist: bool
    first_tower_kill: bool
    first_tower_assist: bool
    combat_player_score: int
    objective_player_score: int
    total_player_score: int
    total_score_rank: int
    player_score0: int
    player_score1: int
    player_score2: int
    player_score3: int
    player_score4: int
    player_score5: int
    player_score6: int
    player_score7: int
    player_score8: int
    player_score9: int
    perk0: int
    perk0_var1: int
    perk0_var2: int
    perk0_var3: int
    perk1: int
    perk1_var1: int
    perk1_var2: int
    perk1_var3: int
    perk2: int
    perk2_var1: int
    perk2_var2: int
    perk2_var3: int
    perk3: int
    perk3_var1: int
    perk3_var2: int
    perk3_var3: int
    perk4: int
    perk4_var1: int
    perk4_var2: int
    perk4_var3: int
    perk5: int
    perk5_var1: int
    perk5_var2: int
    perk5_var3: int
    perk_primary_style: int
    perk_sub_style: int
    stat_perk0: int
    stat_perk1: int
    stat_perk2: int


class MasteryDto(BaseModel):
    rank: int
    mastery_id: int


class ParticipantDto(BaseModel):
    participant_id: int
    team_id: int
    champion_id: int
    spell1_id: int
    spell2_id: int
    stats: ParticipantStatsDto
    timeline: ParticipantTimelineDto
    highest_achieved_season_tier: Optional[str]
    masteries: Optional[List[MasteryDto]]


class TeamBansDto(BaseModel):
    champion_id: int
    pick_turn: int


class TeamStatsDto(BaseModel):
    team_id: int
    win: str
    first_blood: bool
    first_tower: bool
    first_inhibitor: bool
    first_baron: bool
    first_dragon: bool
    first_rift_herald: bool
    tower_kills: int
    inhibitor_kills: int
    baron_kills: int
    dragon_kills: int
    vilemaw_kills: int
    rift_herald_kills: int
    dominion_victory_score: int
    bans: List[TeamBansDto]


class MatchDto(BaseModel):
    game_id: int
    platform_id: str
    game_creation: int
    game_duration: int
    queue_id: int
    map_id: int
    season_id: int
    game_version: str
    game_mode: str
    game_type: str
    teams: List[TeamStatsDto]
    participants: List[ParticipantDto]
    participant_identities: List[ParticipantIdentityDto]


class MatchPositionDto(BaseModel):
    x: int
    y: int


class MatchEventDto(BaseModel):
    lane_type: Optional[str]
    skill_slot: Optional[int]
    ascended_type: Optional[str]
    creator_id: Optional[int]
    after_id: Optional[int]
    event_type: Optional[str]
    type: str
    level_up_type: Optional[str]
    ward_type: Optional[str]
    participant_id: Optional[int]
    tower_type: Optional[str]
    item_id: Optional[int]
    before_id: Optional[int]
    point_captured: Optional[str]
    monster_type: Optional[str]
    monster_sub_type: Optional[str]
    team_id: Optional[int]
    position: Optional[MatchPositionDto]
    killer_id: Optional[int]
    timestamp: int
    assisting_participant_ids: Optional[List[int]]
    building_type: Optional[str]
    victim_id: Optional[int]


class MatchParticipantFrameDto(BaseModel):
    participant_id: int
    minions_killed: int
    team_score: int
    dominion_score: int
    total_gold: int
    level: int
    xp: int
    current_gold: int
    position: MatchPositionDto
    jungle_minions_killed: int


class MatchFrameDto(BaseModel):
    participant_frames: Dict[str, MatchParticipantFrameDto]
    events: List[MatchEventDto]
    timestamp: int


class MatchTimelineDto(BaseModel):
    frames: List[MatchFrameDto]
    frame_interval: int


class MatchReferenceDto(BaseModel):
    platform_id: str
    game_id: int
    champion: int
    queue: int
    season: int
    timestamp: int
    role: str
    lane: str


class MatchlistDto(BaseModel):
    matches: List[MatchReferenceDto]
    start_index: int
    end_index: int
    total_games: int



from typing import List

from .base import BaseModel


class MiniSeriesDto(BaseModel):
    losses: int
    progress: str
    target: int
    wins: int


class LeagueEntryDto(BaseModel):
    league_id: str
    summoner_id: str
    summoner_name: str
    queue_type: str
    tier: str
    rank: str
    league_points: int
    wins: int
    losses: int
    hot_streak: bool
    veteran: bool
    fresh_blood: bool
    inactive: bool
    mini_series: MiniSeriesDto


class LeagueItemDto(BaseModel):
    fresh_blood: bool
    wins: int
    summoner_name: str
    mini_series: MiniSeriesDto
    inactive: bool
    veteran: bool
    hot_streak: bool
    rank: str
    league_points: int
    losses: int
    summoner_id: str


class LeagueListDto(BaseModel):
    league_id: str
    entries: List[LeagueItemDto]
    tier: str
    name: str
    queue: str



from typing import Optional, Literal

from requests import Session

from .context import RiotGamesApiContext
from .summoner import SummonerApiV4
from .champion import ChampionApiV3
from .match import MatchApiV4
from .clash import ClashApiV1
from .account import AccountApiV1
from .champion_mastery import ChampionMasteryApiV4
from .spectator import SpectatorApiV4
from .lol_status import LolStatusApiV4
from .league import LeagueApiV4
from .league_exp import LeagueExpApiV4


class RiotGamesApi:
    def __init__(self, token: str, default_platform: Optional[str] = None):
        self._ctx = RiotGamesApiContext(token, default_platform)
        self._session = Session()
        self.summoner = SummonerApiV4(self._ctx, self._session)
        self.champion = ChampionApiV3(self._ctx, self._session)
        self.match = MatchApiV4(self._ctx, self._session)
        self.clash = ClashApiV1(self._ctx, self._session)
        self.account = AccountApiV1(self._ctx, self._session)
        self.champion_mastery = ChampionMasteryApiV4(self._ctx, self._session)
        self.spectator = SpectatorApiV4(self._ctx, self._session)
        self.lol_status = LolStatusApiV4(self._ctx, self._session)
        self.league = LeagueApiV4(self._ctx, self._session)
        self.league_exp = LeagueExpApiV4(self._ctx, self._session)

    def set_default_platform(self, platform: str):
        self._ctx.default_platform = platform



from typing import List

from .base import BaseModel


class GameCustomizationObject(BaseModel):
    category: str
    content: str


class Perks(BaseModel):
    perk_ids: List[int]
    perk_style: int
    perk_sub_style: int


class CurrentGameParticipant(BaseModel):
    champion_id: int
    perks: Perks
    profile_icon_id: int
    bot: bool
    team_id: int
    summoner_name: str
    summoner_id: str
    spell1_id: int
    spell2_id: int
    game_customization_objects: List[GameCustomizationObject]


class Observer(BaseModel):
    encryption_key: str


class BannedChampion(BaseModel):
    pick_turn: int
    champion_id: int
    team_id: int


class CurrentGameInfo(BaseModel):
    game_id: int
    game_type: str
    game_start_time: int
    map_id: int
    game_length: int
    platform_id: str
    game_mode: str
    banned_champions: List[BannedChampion]
    game_queue_config_id: int
    observers: Observer
    participants: List[CurrentGameParticipant]


from typing import Optional, List

from pydantic import parse_obj_as

from .models.clash import PlayerDto, TeamDto, TournamentDto
from .base import RiotGamesApiBase


class ClashApiV1(RiotGamesApiBase):
    def get_clash_teams(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> List[PlayerDto]:
        data = self._request(f"/lol/clash/v1/players/by-summoner/{summoner_id}", platform)

        return parse_obj_as(List[PlayerDto], data)

    def get_team(
            self,
            team_id: str,
            platform: Optional[str] = None
    ) -> TeamDto:
        data = self._request(f"/lol/clash/v1/teams/{team_id}", platform)

        return TeamDto.parse_obj(data)

    def get_tournaments(
            self,
            platform: Optional[str] = None
    ) -> List[TournamentDto]:
        data = self._request(f"/lol/clash/v1/tournaments", platform)

        return parse_obj_as(List[TournamentDto], data)

    def get_tournament_by_team(
            self,
            team_id: str,
            platform: Optional[str] = None
    ) -> TournamentDto:
        data = self._request(f"/lol/clash/v1/tournaments/by-team/{team_id}", platform)

        return TournamentDto.parse_obj(data)

    def get_tournament(
            self,
            tournament_id: int,
            platform: Optional[str] = None
    ) -> TournamentDto:
        data = self._request(f"/lol/clash/v1/tournaments/{tournament_id}", platform)

        return TournamentDto.parse_obj(data)



from pydantic import BaseModel as PydanticBaseModel
from humps.camel import case as camelcase


class BaseModel(PydanticBaseModel):
    class Config:
        alias_generator = camelcase
        allow_population_by_field_name = True



from typing import Optional

from .base import RiotGamesApiBase
from .models.champion import ChampionInfo


class ChampionApiV3(RiotGamesApiBase):
    def champion_rotations(
            self,
            platform: Optional[str] = None
    ) -> ChampionInfo:
        data = self._request("/lol/platform/v3/champion-rotations", platform)

        return ChampionInfo.parse_obj(data)



from typing import Optional, List

from .base import BaseModel


class PlayerDto(BaseModel):
    summoner_id: str
    team_id: Optional[str]
    position: str
    role: str


class TeamDto(BaseModel):
    id: str
    tournament_id: int
    name: str
    icon_id: int
    tier: int
    captain: str
    abbreviation: str
    players: List[PlayerDto]


class TournamentPhaseDto(BaseModel):
    id: int
    registration_time: int
    start_time: int
    cancelled: bool


class TournamentDto(BaseModel):
    id: int
    theme_id: int
    name_key: str
    name_key_secondary: str
    schedule: List[TournamentPhaseDto]



from typing import Optional, List

from pydantic import parse_obj_as

from .models.champion_mastery import ChampionMasteryDto
from .base import RiotGamesApiBase


class ChampionMasteryApiV4(RiotGamesApiBase):
    def get_masteries(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> List[ChampionMasteryDto]:
        data = self._request(f"/lol/champion-mastery/v4/champion-masteries/by-summoner/{summoner_id}", platform)

        return parse_obj_as(list[ChampionMasteryDto], data)

    def get_mastery(
            self,
            summoner_id: str,
            champion_id: int,
            platform: Optional[str] = None
    ) -> ChampionMasteryDto:
        data = self._request(
            f"/lol/champion-mastery/v4/champion-masteries/by-summoner/{summoner_id}/by-champion/{champion_id}",
            platform
        )

        return ChampionMasteryDto.parse_obj(data)

    def get_mastery_score(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> int:
        return self._request(f"/lol/champion-mastery/v4/scores/by-summoner/{summoner_id}", platform)



from typing import Optional

from .models.account import AccountDto
from .base import RiotGamesApiBase


class AccountApiV1(RiotGamesApiBase):
    def get_account_by_puuid(
            self,
            puuid: str,
            platform: Optional[str]
    ) -> AccountDto:
        data = self._request(f"/riot/account/v1/accounts/by-puuid/{puuid}", platform)

        return AccountDto.parse_obj(data)

    def get_account_by_riot_id(
            self,
            game_name: str,
            tag_line: str,
            platform: Optional[str] = None
    ) -> AccountDto:
        data = self._request(f"/riot/account/v1/accounts/by-riot-id/{game_name}/{tag_line}", platform)

        return AccountDto.parse_obj(data)

    def get_account_by_game_and_puuid(
            self,
            game: str,
            puuid: str,
            platform: Optional[str] = None
    ) -> AccountDto:
        data = self._request(f"/riot/account/v1/active-shards/by-game/{game}/by-puuid/{puuid}", platform)

        return AccountDto.parse_obj(data)



from typing import List

from .base import BaseModel


class ContentDto(BaseModel):
    locale: str
    content: str


class UpdateDto(BaseModel):
    id: int
    author: str
    publish: bool
    publish_locations: List[str]
    translations: List[ContentDto]
    created_at: str
    updated_at: str


class StatusDto(BaseModel):
    id: int
    maintenance_status: str
    incident_severity: str
    titles: List[ContentDto]
    updates: List[UpdateDto]
    created_at: str
    archive_at: str
    updated_at: str
    platforms: List[str]


class PlatformDataDto(BaseModel):
    id: str
    name: str
    locales: List[str]
    maintances: List[StatusDto]
    incidents: List[StatusDto]



from typing import Optional, List

from pydantic import parse_obj_as

from .base import RiotGamesApiBase
from .models.league import LeagueListDto, LeagueEntryDto


class LeagueApiV4(RiotGamesApiBase):
    def get_challenger_queues(
            self,
            queue: str,
            platform: Optional[str] = None
    ) -> LeagueListDto:
        data = self._request(f"/lol/league/v4/challengerleagues/by-queue/{queue}", platform)

        return LeagueListDto.parse_obj(data)

    def get_grandmaster_queues(
            self,
            queue: str,
            platform: Optional[str] = None
    ) -> LeagueListDto:
        data = self._request(f"/lol/league/v4/grandmasterleagues/by-queue/{queue}", platform)

        return LeagueListDto.parse_obj(data)

    def get_master_queues(
            self,
            queue: str,
            platform: Optional[str] = None
    ) -> LeagueListDto:
        data = self._request(f"/lol/league/v4/masterleagues/by-queue/{queue}", platform)

        return LeagueListDto.parse_obj(data)

    def get_leagues(
            self,
            league_id: str,
            platform: Optional[str] = None
    ) -> LeagueListDto:
        data = self._request(f"/lol/league/v4/leagues/{league_id}", platform)

        return LeagueListDto.parse_obj(data)

    def get_entries_by_summoner_id(
            self,
            summoner_id: str,
            platform: Optional[str] = None
    ) -> List[LeagueEntryDto]:
        data = self._request(f"/lol/league/v4/entries/by-summoner/{summoner_id}", platform)

        return parse_obj_as(List[LeagueEntryDto], data)

    def get_entries(
            self,
            queue: str,
            tier: str,
            division: str,
            platform: Optional[str] = None
    ) -> List[LeagueEntryDto]:
        data = self._request(f"/lol/league/v4/entries/{queue}/{tier}/{division}", platform)

        return parse_obj_as(List[LeagueEntryDto], data)



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="riot-games-api",
    version="1.0.3",
    author="Kirill Shikhalev",
    author_email="esbraff@yandex.ru",
    description="Riot Games API wrapper for Python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/esbraff/riot_games_api",
    project_urls={
        "Bug Tracker": "https://github.com/esbraff/riot_games_api/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    install_requires=[
        "requests>=2.5.0",
        "pydantic~=1.8.1",
        "humps~=0.2.2",
    ],
    python_requires=">=3.6",
)



from typing import Literal, Optional

from .exceptions import RiotGamesApiException


class RiotGamesApiContext:
    def __init__(self, token: str, default_platform: Optional[str]):
        self.token = token
        self.default_platform = default_platform

    def get_base_url(self, platform: Optional[str] = None):
        platform = platform or self.default_platform

        if platform is None:
            raise RiotGamesApiException from RuntimeError("platform must be specified")

        return f"https://{platform}.api.riotgames.com/"
